@@ -297,6 +297,12 @@ namespace Tomboy
 						    0,
 						    0);
 			
+			// Create a new note
+			global_keys.AddAccelerator (new EventHandler (CreateNewNote),
+							(uint) Gdk.Key.n,
+							Gdk.ModifierType.ControlMask,
+							Gtk.AccelFlags.Visible);
+			
 			// Have Esc key close the note window
 			KeyPressEvent += KeyPressed;
 						   
@@ -777,6 +783,11 @@ namespace Tomboy
 		{
 			GuiUtils.ShowHelp ("tomboy.xml", "editing-notes", Screen, this);
 		}
+		
+		void CreateNewNote (object sender, EventArgs args)
+		{
+			Tomboy.ActionManager ["NewNoteAction"].Activate ();
+		}
 
 		void SearchButtonClicked ()
 		{
@@ -1021,9 +1032,6 @@ namespace Tomboy
 
 			string [] words = text.Split (' ', '\t', '\n');
 
-			// Used for matching in the raw note XML
-			string [] encoded_words = XmlEncoder.Encode (text).Split (' ', '\t', '\n');
-
 			current_matches = 
 				FindMatchesInBuffer (note.Buffer, 
 						     words, 
