@@ -777,13 +777,17 @@ update_page_size_and_margins (GtkSourcePrintJob *job)
 						   &job->priv->page_width,
 						   &job->priv->page_height);
 
-	gnome_print_config_get_length (job->priv->config, GNOME_PRINT_KEY_PAGE_MARGIN_TOP,
+	gnome_print_config_get_length (job->priv->config, 
+				       (const guchar *) GNOME_PRINT_KEY_PAGE_MARGIN_TOP,
 				       &job->priv->doc_margin_top, NULL);
-	gnome_print_config_get_length (job->priv->config, GNOME_PRINT_KEY_PAGE_MARGIN_BOTTOM,
+	gnome_print_config_get_length (job->priv->config, 
+				       (const guchar *) GNOME_PRINT_KEY_PAGE_MARGIN_BOTTOM,
 				       &job->priv->doc_margin_bottom, NULL);
-	gnome_print_config_get_length (job->priv->config, GNOME_PRINT_KEY_PAGE_MARGIN_LEFT,
+	gnome_print_config_get_length (job->priv->config, 
+				       (const guchar *) GNOME_PRINT_KEY_PAGE_MARGIN_LEFT,
 				       &job->priv->doc_margin_left, NULL);
-	gnome_print_config_get_length (job->priv->config, GNOME_PRINT_KEY_PAGE_MARGIN_RIGHT,
+	gnome_print_config_get_length (job->priv->config, 
+				       (const guchar *) GNOME_PRINT_KEY_PAGE_MARGIN_RIGHT,
 				       &job->priv->doc_margin_right, NULL);
 
 	/* set default fonts for numbers and header/footer */
@@ -923,7 +927,7 @@ font_description_to_gnome_font_name (PangoFontDescription *desc)
  * gnome_font_face_find_closest() (probably a gnome-print bug)
  */
 static void
-face_and_size_from_full_name (const guchar   *name,
+face_and_size_from_full_name (const gchar   *name,
 			      GnomeFontFace **face,
 			      gdouble        *size)
 {
@@ -943,7 +947,7 @@ face_and_size_from_full_name (const guchar   *name,
 		*size = 12;
 	}
 
-	*face = gnome_font_face_find_closest (copy);
+	*face = gnome_font_face_find_closest ((const guchar *) copy);
 	g_free (copy);
 }
 
@@ -963,7 +967,8 @@ font_description_from_gnome_font_name (const char *font_name)
 	style = gnome_font_face_is_italic (face) ? PANGO_STYLE_ITALIC : PANGO_STYLE_NORMAL;
 
 	desc = pango_font_description_new ();
-	pango_font_description_set_family (desc, gnome_font_face_get_family_name (face));
+	pango_font_description_set_family (desc, 
+					   (const char *) gnome_font_face_get_family_name (face));
 	pango_font_description_set_weight (desc, weight);
 	pango_font_description_set_style (desc, style);
 	pango_font_description_set_size (desc, size * PANGO_SCALE);
@@ -980,8 +985,6 @@ text_style_new (GtkSourcePrintJob *job, GtkTextTag *tag)
 {
 	TextStyle *style;
 	gboolean bg_set, fg_set;
-	gdouble scale;
-	PangoFontDescription *font_desc;
 	
 	g_return_val_if_fail (tag != NULL && GTK_IS_TEXT_TAG (tag), NULL);
 
@@ -1322,7 +1325,8 @@ create_layout_for_para (GtkSourcePrintJob *job,
 				add_attribute_to_list (attr, attrs, index, seg_len);
 			}
 
-			if (seg->style->underline != PANGO_UNDERLINE_NONE)
+			if (seg->style->underline != PANGO_UNDERLINE_NONE &&
+			    seg->style->underline != PANGO_UNDERLINE_ERROR)
 			{
 				attr = pango_attr_underline_new (seg->style->underline);
 				add_attribute_to_list (attr, attrs, index, seg_len);
@@ -1603,7 +1607,7 @@ print_page (GtkSourcePrintJob *job)
 	while (l != NULL)
 	{
 		Paragraph *para = l->data;
-		gdouble baseline;
+		gdouble baseline = 0;
 		gint last_line = line;
 		
 		line = print_paragraph (job, para, line, x, &y, &baseline, force_fit);
